@@ -1,12 +1,17 @@
 from enum import Enum
+from hbshare.base.upass import is_prod_env
 
-DOMAINS = {'hbcgi': 'data.howbuy.com', 's': 's.howbuy.com','ams':'ams-data.intelnal.howbuy.com'}
+# 办公环境
+DOMAINS_OFFICE = {'hbcgi': 'data.howbuy.com', 's': 's.howbuy.com','ams':'ams-data.intelnal.howbuy.com'}
+# 产线环境
+DOMAINS_PROD = {'hbcgi': 'data.howbuy.com', 's': 's.howbuy.com','ams':'ams.inner.howbuy.com'}
 P_TYPE = {'http': 'http://', 'ftp': 'ftp://', 'https': 'https://'}
 
 class UrlCfg():
-    def __init__(self, url, method, parsePostDataFunc, parseParamsFunc, supportFields):
-        self.url = url
+    def __init__(self, url, method,domain,parsePostDataFunc, parseParamsFunc, supportFields):
+        self.__url__ = url
         self.method = method
+        self.__domain__ = domain
         self.__parsePostDataFunc__ = parsePostDataFunc
         self.__parseParamsFunc__ = parseParamsFunc
         self.supportFields = supportFields
@@ -17,7 +22,10 @@ class UrlCfg():
     def parseParams(self, kwargs):
         return self.__parseParamsFunc__(kwargs)
 
-
+    def getUrl(self):
+        if is_prod_env():
+            return self.__url__ % DOMAINS_PROD.get(self.__domain__)
+        return self.__url__ % DOMAINS_OFFICE.get(self.__domain__)
 
     def supportFields(self):
         return self.supportFields
@@ -36,7 +44,7 @@ class UrlEnum(Enum):
 
 ############################### 指数 ###############################
     # 查询指数行情
-    MARKET_HQ = UrlCfg('%s%s/data/fund/brinson/zsjy' % (P_TYPE['http'], DOMAINS['ams']), 'post',
+    MARKET_HQ = UrlCfg('http://%s/data/fund/brinson/zsjy','post', 'ams',
                        lambda x: {
                            'zqdm': x['zqdm'],
                            'jyrq': {
@@ -58,7 +66,7 @@ class UrlEnum(Enum):
 
 ################################ 公募 ################################
     # 公募基金回报
-    FUND_JJHB = UrlCfg('%s%s/data/fund/brinson/jjhb' % (P_TYPE['http'], DOMAINS['ams']), 'post',
+    FUND_JJHB = UrlCfg('http://%s/data/fund/brinson/jjhb','post', 'ams',
                        lambda x: {
                            'jjdm': x['jjdm'],
                            'jzrq': {
@@ -82,7 +90,7 @@ class UrlEnum(Enum):
                        )
     '''公募基金回报'''
     # 公募基金公募持仓数据
-    FUND_JJ_GPZH = UrlCfg('%s%s/data/fund/brinson/gpzh' % (P_TYPE['http'], DOMAINS['ams']), 'post',
+    FUND_JJ_GPZH = UrlCfg('http://%s/data/fund/brinson/gpzh' ,'post','ams',
                           lambda x: {
                               'jjdm': x['jjdm'],
                               'ggrq': {
@@ -101,7 +109,7 @@ class UrlEnum(Enum):
                           )
     '''公募基金公募持仓数据'''
     # 公募持仓资产比例数据
-    FUND_JJ_ZCPZ = UrlCfg('%s%s/data/fund/brinson/zcpz' % (P_TYPE['http'], DOMAINS['ams']), 'post',
+    FUND_JJ_ZCPZ = UrlCfg('http://%s/data/fund/brinson/zcpz','post','ams',
                           lambda x: {
                               'jjdm': x['jjdm'],
                               'jsrq': {
@@ -128,7 +136,7 @@ class UrlEnum(Enum):
     '''公募持仓资产比例数据'''
 
     # 指数成分股数据
-    MARKET_CFG = UrlCfg('%s%s/data/fund/brinson/lc_icw' % (P_TYPE['http'], DOMAINS['ams']), 'post',
+    MARKET_CFG = UrlCfg('http://%s/data/fund/brinson/lc_icw', 'post','ams',
                         lambda x: {
                             'secuCode': x['secuCode'],
                             'endDate': x['endDate'],
@@ -143,7 +151,7 @@ class UrlEnum(Enum):
     '''指数成分股数据'''
 
     # 公私募净值归因 - Barra风格因子数据
-    BARRA_FACTORY = UrlCfg('%s%s/data/fund/jzgy/barra_factor_return' % (P_TYPE['http'], DOMAINS['ams']), 'post',
+    BARRA_FACTORY = UrlCfg('http://%s/data/fund/jzgy/barra_factor_return' ,'post','ams',
                                 lambda x: {
                                     'tradeDate': {
                                         'startDate': x['startDate'],
@@ -160,7 +168,7 @@ class UrlEnum(Enum):
     '''公私募净值归因 - Barra风格因子数据'''
 
     #  全量指数行情数据
-    MARKET_HQQL = UrlCfg('%s%s/data/fund/jzgy/hqql' % (P_TYPE['http'], DOMAINS['ams']), 'post',
+    MARKET_HQQL = UrlCfg('http://%s/data/fund/jzgy/hqql' ,'post','ams',
                          lambda x: {
                              'zqdm': x['zqdm'],
                              'jyrq': {
@@ -179,7 +187,7 @@ class UrlEnum(Enum):
     ''' 全量指数行情数据'''
 
     #  公私募净值归因 - 板块指数数据
-    SECTOR_FACTOR = UrlCfg('%s%s/data/fund/jzgy/sector_factor' % (P_TYPE['http'], DOMAINS['ams']), 'post',
+    SECTOR_FACTOR = UrlCfg('http://%s/data/fund/jzgy/sector_factor' ,'post','ams',
                            lambda x: {
                                'tradeDate': {
                                    'startDate': x['startDate'],
@@ -196,7 +204,7 @@ class UrlEnum(Enum):
     ''' 公私募净值归因 - 板块指数数据 '''
 
     #  私募基金回报数据
-    SIMU_RHB = UrlCfg('%s%s/data/fund/jzgy/rhb' % (P_TYPE['http'], DOMAINS['ams']), 'post',
+    SIMU_RHB = UrlCfg('http://%s/data/fund/jzgy/rhb' ,'post','ams',
                       lambda x: {
                           'jjdm': x['jjdm'],
                           'jzrq': {
@@ -212,8 +220,10 @@ class UrlEnum(Enum):
                                      'hbcl', 'hbfh', 'fqdwjz',)
                       )
     ''' 私募基金回报数据 '''
-    # A股市场估值数据/科创板估值数据
-    SC_VALUATION = UrlCfg('%s%s/data/fund/sac/dfv_stibdifv' % (P_TYPE['http'], DOMAINS['ams']), 'post',
+
+################################ A股市场/科创板 ################################    
+    # A股市场估值数据
+    SC_VALUATION_A = UrlCfg('http://%s/data/fund/sac/dfv_stibdifv_a' ,'post','ams',
                           lambda x: {
                               'tradingDay': {
                                   'startDate': x['startDate'],
@@ -233,9 +243,31 @@ class UrlEnum(Enum):
                                          'evtoebitdarandd', 'totalmvtorandd', 'mva', 'floatmva', 'marketvaluetodebt1',
                                          'marketvaluetodebt2', 'debttoassetvalue1', 'debttoassetvalue2',)
                           )
-    ''' A股市场估值数据/科创板估值数据 '''
-    # A股市场复权行情数据/科创板复权行情数据
-    SC_FQ = UrlCfg('%s%s/data/fund/brinson/pd_stibpd' % (P_TYPE['http'], DOMAINS['ams']), 'post',
+    ''' A股市场估值数据 '''
+    # 科创板估值数据
+    SC_VALUATION_KC = UrlCfg('http://%s/data/fund/sac/dfv_stibdifv_kc' ,'post','ams',
+                          lambda x: {
+                              'tradingDay': {
+                                  'startDate': x['startDate'],
+                                  'endDate': x['endDate']
+                              },
+                              'fields': x['fields'],
+                              'page': x['page'],
+                              'perPage': x['perPage']
+                          },
+                          lambda y: {},
+                          supportFields=('innercode', 'tradingday', 'pe', 'pb', 'pcf', 'ps', 'dividendratio', 'updatetime', 'jsid',
+                                         'psttm', 'totalmv', 'negotiablemv', 'pelyr', 'pcfttm', 'pcfs', 'pcfsttm', 'dividendratiolyr',
+                                         'enterprisevaluew', 'enterprisevaluen', 'inserttime', 'totalmv2', 'totalasmv', 'pettmcut',
+                                         'forwardpeqa', 'forwardpehr', 'peg', 'pettmtoorrate', 'forwardpcfqa', 'forwardpcfhr',
+                                         'forwardpcfsqa', 'forwardpcfshr', 'forwardpsqa', 'forwardpshr', 'dividendratiolyr2',
+                                         'dividendratio2', 'evtoebitda', 'evtoor', 'evtofcff', 'evtocfo', 'evtogp', 'per',
+                                         'evtoebitdarandd', 'totalmvtorandd', 'mva', 'floatmva', 'marketvaluetodebt1',
+                                         'marketvaluetodebt2', 'debttoassetvalue1', 'debttoassetvalue2',)
+                          )
+    ''' 科创板估值数据 '''
+    # A股市场复权行情数据
+    SC_FQ_A = UrlCfg('http://%s/data/fund/brinson/pd_stibpd_a' ,'post','ams',
                           lambda x: {
                               'tradingDay': {
                                   'startDate': x['startDate'],
@@ -256,12 +288,11 @@ class UrlEnum(Enum):
                                 'updatetime','jsid','highestpricermthree','lowestpricermthree','highestpricermsix',
                                 'lowestpricermsix','highestpricery','lowestpricery','inserttime',)
                           )
-    '''A股市场复权行情数据/科创板复权行情数据'''
-    # 行情数据 FINCHINA.CHDQUOTE 股票中国历史日交易 
-    SC_CHDQUOTE =  UrlCfg('%s%s/data/fund/brinson/chdquote' % (P_TYPE['http'], DOMAINS['ams']), 'post',
+    '''A股市场复权行情数据'''
+    #科创板复权行情数据
+    SC_FQ_KC = UrlCfg('http://%s/data/fund/brinson/pd_stibpd_kc','post','ams',
                           lambda x: {
-                              'symbol': x['symbol'],
-                              'tdate': {
+                              'tradingDay': {
                                   'startDate': x['startDate'],
                                   'endDate': x['endDate']
                               },
@@ -270,7 +301,16 @@ class UrlEnum(Enum):
                               'perPage': x['perPage']
                           },
                           lambda y: {},
-                          supportFields=('tdate','exchange','symbol','sname','lclose','topen','tclose','high','low',
-                            'voturnover','vaturnover','ndeals','avgprice','avgvolpd','avgvapd','chg',
-                            'pchg','prange','mcap','tcap','turnover','entrydate','entrytime','tmstamp',)
-                          )
\ No newline at end of file
+                          supportFields=('id','innercode','tradingday','closeprice','changepct','backwardprice',
+                                'risingupdays','fallingdowndays','maxrisingupdays','maxfallingdowndays',
+                                'fallondebut','fallonnaps','ahpremiumrate50','stockboard','limitboard',
+                                'surgedlimit','declinelimit','highestprice','lowestprice','highestpricerw',
+                                'lowestpricerw','highestpricetw','lowestpricetw','highestpricerm','lowestpricerm',
+                                'highestpricetm','lowestpricetm','highestpricer3m','lowestpricer3m','highestpricer6m',
+                                'lowestpricer6m','highestpriceytd','lowestpriceytd','highestpricer12m','lowestpricer12m',
+                                'updatetime','jsid','highestpricermthree','lowestpricermthree','highestpricermsix',
+                                'lowestpricermsix','highestpricery','lowestpricery','inserttime',)
+                          )
+    '''科创板复权行情数据'''
+
+
