@@ -1,5 +1,7 @@
 from hbshare.db.ApiCfg import UrlEnum
-import hbshare as hbs
+# from ApiCfg import UrlEnum
+from hbshare.base.data_pro import hb_api
+# import hbshare as hbs
 import pandas as pd
 import time
 
@@ -31,10 +33,10 @@ def commonQuery(urlEnum, pause=0.01, timeout=10,**kwargs):
         kwargs = {}
     # 判断目标字段是否指定，没指定则使用接口支持字段
     fieldsCheckd(kwargs,cfg.supportFields)
-    api = hbs.hb_api(timeout=timeout)
+    api = hb_api(timeout=timeout)
     pages = 1
     page = 1
-    perPage = 100
+    perPage = 1000
     data = []
     while page <= pages:
         kwargs['page'] = page
@@ -47,7 +49,7 @@ def commonQuery(urlEnum, pause=0.01, timeout=10,**kwargs):
         except KeyError as e:
             raise RuntimeError("Use commonQuery(%s) failed,parameter %s not found" % (urlEnum,e.args[0]))
 
-        org_js = api.query(cfg.url, method=cfg.method, params=params,post_data=post_data)
+        org_js = api.query(cfg.getUrl(), method=cfg.method, params=params,post_data=post_data)
         status_code = str(org_js['code'])
         if status_code != '0000':
             status = str(org_js['desc'])
@@ -76,5 +78,5 @@ def commonQuery(urlEnum, pause=0.01, timeout=10,**kwargs):
 
 if __name__ == '__main__':
 
-    data = commonQuery(UrlEnum.FUND_JJHB,jjdm = '000001',startDate='20060104',endDate='20071025')
-    print(data)
\ No newline at end of file
+    data = commonQuery('SC_VALUATION_A', startDate ='2019-07-22 00:00:00', endDate='2019-07-22 00:00:00')
+    print(data)
