@@ -7,6 +7,9 @@ import numpy as np
 from hbshare.fe.XZ import db_engine
 import plotly
 from scipy.optimize import shgo
+import cvxopt.solvers as sol
+from cvxopt import matrix as mat
+sol.options['show_progress'] = False
 
 hbdb=db_engine.HBDB()
 
@@ -231,30 +234,46 @@ class Untils:
     @staticmethod
     # 写一个通用的多元一次回归的算法模型，自变量个数不确定
     def my_general_linear_model_func(A1, b1):
-        num_x = np.shape(A1)[1]
 
-        def my_func(x):
-            ls = 0.5 * (b1 - np.dot(A1, x)) ** 2
-            result = np.sum(ls)
-            return result
+        P = 2 * np.dot(np.transpose(A1), A1)
+        Q = - 4 * np.dot(np.transpose(A1), b1)
+        P = mat(P)
+        Q = mat(Q)
 
-        def g1(x):
-            return np.sum(x)  # sum of X >= 0
+        lb=[0]*A1.shape[1]
+        ub=[1]*A1.shape[1]
 
-        def g2(x):
-            return 1 - np.sum(x)  # sum of X <= 1
+        G = mat(np.vstack((np.diag([-1]*A1.shape[1]), np.diag([1]*A1.shape[1]))), tc='d')
+        h = mat(np.array(lb+ub), tc='d') # 为各参数的上下限！！！！
+        A = mat(np.array([[1]*A1.shape[1]]), tc='d')
+        b = mat(np.array([1]), tc='d')
 
-        cons = ({'type': 'ineq', 'fun': g1}
-                , {'type': 'eq', 'fun': g2})
-        x0 = np.zeros(num_x)
-        bnds = [(0, 1)]
-        for i in range(num_x - 1):
-            bnds.append((0, 1))
-        res1 = shgo(my_func,
-                    bounds=bnds,
-                    constraints=cons)
+        result = sol.qp(P, Q,G, h, A, b)
 
-        return res1
+        # num_x = np.shape(A1)[1]
+        #
+        # def my_func(x):
+        #     ls = 0.5 * (b1 - np.dot(A1, x)) ** 2
+        #     result = np.sum(ls)
+        #     return result
+        #
+        # def g1(x):
+        #     return np.sum(x)  # sum of X >= 0
+        #
+        # def g2(x):
+        #     return 1-np.sum(x)  # sum of X <= 1
+        #
+        # cons = ({'type': 'eq', 'fun': g2}
+        #         , {'type': 'ineq', 'fun': g1})
+        # x0 = np.zeros(num_x)
+        # bnds = [(0, 1)]
+        # for i in range(num_x - 1):
+        #     bnds.append((0, 1))
+        # res1 = shgo(my_func,
+        #             bounds=bnds,
+        #             constraints=cons)
+
+        return [ x for x in result['x']]
 
 class Plot:
     def __init__(self,fig_width,fig_height):
@@ -266,7 +285,7 @@ class Plot:
         kwargs['output_type'] = 'div'
         plot_str = plotly.offline.plot({"data": data, "layout": layout}, **kwargs)
         print('%%angular <div style="height: %ipx; width: %spx"> %s </div>' % (self.fig_height, self.fig_width, plot_str))
-    #
+
     # def plot_render(self,data,layout):
     #     fig = go.Figure(data=data, layout=layout)
     #     fig.show()
