@@ -137,8 +137,7 @@ def tswr(start_date, price_field='CLOSE', lag=1, **kwargs):
             on='UCODE', how='left'
         )
         data_wr_range['FACTORVALUE'] = data_wr_range['WR1'] - data_wr_range['WR0']
-        # data_wr_range['POS'] = data_wr_range['FACTORVALUE'] / data_wr_range['FACTORVALUE'].abs() * -1
-        # data_wr_range['POS'] = data_wr_range['POS'].fillna(0)
+
         data_wr_range = ts_pos(data=data_wr_range, direction=-1)
 
         data_t = data[
@@ -560,15 +559,8 @@ def xswr(start_date, price_field='CLOSE', lag=1, **kwargs):
             data_wr_range[data_wr_range['WR0'] > 0]['WR1'] / data_wr_range[data_wr_range['WR0'] > 0]['WR0'] - 1
         )
 
-        # quantile_p = data_wr_range['FACTORVALUE'].quantile(quantile / 100)
-        # quantile_n = data_wr_range['FACTORVALUE'].quantile(1 - quantile / 100)
-        # data_wr_range['POS'] = data_wr_range['FACTORVALUE'].apply(
-        #     lambda x: -1 if x > quantile_p else (1 if x < quantile_n else 0)
-        # )
         data_wr_range = xs_pos(data=data_wr_range, direction=-1, quantile=quantile)
 
-        # data_wr_range['POS'] = data_wr_range['POS'].fillna(0)
-
         data_t = data[
             np.array(data['TDATE'] == t_date) & np.array(data['VOL'] > kwargs['min_volume'])
             ][['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', price_field]]
@@ -678,6 +670,76 @@ def mr(start_date, price_field='CLOSE', lag=1, **kwargs):
     ].reset_index(drop=True)
 
 
+# n日净持仓
+# 净头寸区间总和排序
+def xsmr(start_date, price_field='CLOSE', lag=1, **kwargs):
+    data = kwargs['data']
+    data_mr = kwargs['data_mr']
+    liq_days = kwargs['liq_days']
+    data['UCODE'] = data['EXCHANGE'].apply(lambda x: str(x)) + data['PCODE'].apply(lambda x: str(x))
+    data_mr['UCODE'] = data_mr['EXCHANGE'].apply(lambda x: str(x)) + data_mr['PCODE'].apply(lambda x: str(x))
+
+    calendar = data['TDATE'].drop_duplicates().tolist()
+
+    quantile = kwargs['quantile']
+    window_days = kwargs['window_days']
+    index_name = 'xsmr_d' + str(window_days) + '_q' + str(quantile)
+
+    start_index = calendar.index(np.array(calendar)[np.array(calendar) >= start_date][0])
+
+    positions = pd.DataFrame()
+    for i in range(start_index, len(calendar) - 1):
+        t_date = calendar[i]
+
+        data_mr_t = data_mr[
+            np.array(data_mr['TDATE'] >= calendar[i - lag - window_days])
+            & np.array(data_mr['TDATE'] <= calendar[i - lag])
+            ].groupby(by=['UCODE']).sum()[['MR']].reset_index()
+        data_mr_range = data_mr_t
+
+        data_mr_range['FACTORVALUE'] = data_mr_range['MR']
+
+        data_mr_range = xs_pos(data=data_mr_range, quantile=quantile)
+        data_t = data[
+            np.array(data['TDATE'] == t_date) & np.array(data['VOL'] > kwargs['min_volume'])
+            ][['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', price_field]]
+
+        data_liq = data[
+            data['TDATE'] == calendar[i - liq_days]
+            ][['UCODE']]
+
+        data_t = pd.merge(data_liq, data_t, on='UCODE', how='inner')
+
+        data_tomorrow = data[
+            np.array(data['TDATE'] == calendar[i + 1])
+        ][['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', price_field]]
+
+        data_t = pd.merge(data_t[['UCODE', price_field]], data_mr_range, on='UCODE', how='inner')
+
+        data_t = pd.merge(
+            data_t.rename(columns={price_field: 'CLOSE'}),
+            data_tomorrow.rename(columns={price_field: 'CLOSE1'}),
+            on='UCODE', how='left'
+        )
+
+        data_t['RETURN'] = (data_t['CLOSE1'] / data_t['CLOSE'] - 1) #* data_t['POS']
+
+        # index_all.append(index_all[-1] * (1 + data_t['RETURN'].mean()))
+        data_t['TDATE'] = calendar[i + 1]
+        data_t['FACTOR'] = index_name
+        data_t = xs_weight(data_t)
+        positions = pd.concat([positions, data_t])
+        print(index_name + ', ' + t_date.strftime('%Y-%m-%d') + ', ' + str(sum(data_t['POS'] != 0)))
+    if len(positions) == 0:
+        return
+    positions['WEIGHT'] = positions['WEIGHT'] * 100
+    positions['RETURN'] = positions['RETURN'] * 100
+    # positions['FACTORVALUE'] = positions['FACTORVALUE'] * 100
+    return positions[
+        ['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', 'CLOSE', 'CLOSE1', 'POS', 'RETURN', 'FACTORVALUE', 'FACTOR', 'WEIGHT']
+    ].reset_index(drop=True)
+
+
 # n日净持仓变化
 # 净头寸时序增加做多
 def tsmr(start_date, price_field='CLOSE', lag=1, **kwargs):
@@ -754,6 +816,85 @@ def tsmr(start_date, price_field='CLOSE', lag=1, **kwargs):
     ].reset_index(drop=True)
 
 
+# n日净持仓变化
+# 净头寸时序增加率排序
+def xstsmr(start_date, price_field='CLOSE', lag=1, **kwargs):
+    data = kwargs['data']
+    data_mr = kwargs['data_mr']
+    liq_days = kwargs['liq_days']
+    data['UCODE'] = data['EXCHANGE'].apply(lambda x: str(x)) + data['PCODE'].apply(lambda x: str(x))
+    data_mr['UCODE'] = data_mr['EXCHANGE'].apply(lambda x: str(x)) + data_mr['PCODE'].apply(lambda x: str(x))
+
+    calendar = data['TDATE'].drop_duplicates().tolist()
+
+    quantile = kwargs['quantile']
+    window_days = kwargs['window_days']
+    index_name = 'xstsmr_d' + str(window_days) + '_q' + str(quantile)
+
+    start_index = calendar.index(np.array(calendar)[np.array(calendar) >= start_date][0])
+
+    positions = pd.DataFrame()
+    for i in range(start_index, len(calendar) - 1):
+        t_date = calendar[i]
+        data_mr_0 = data_mr[
+            data_mr['TDATE'] == calendar[i - lag - window_days]
+            ].groupby(by=['UCODE']).sum()[['MR']].reset_index()
+        data_mr_t = data_mr[
+            data_mr['TDATE'] == calendar[i - lag]
+            ].groupby(by=['UCODE']).sum()[['MR']].reset_index()
+
+        data_mr_range = pd.merge(
+            data_mr_0.rename(columns={'MR': 'MR0'}),
+            data_mr_t.rename(columns={'MR': 'MR1'}),
+            on='UCODE', how='left'
+        )
+        # data_mr_range['FACTORVALUE'] = data_mr_range['MR1'] - data_mr_range['MR0']
+        data_mr_range['FACTORVALUE'] = (
+                data_mr_range[data_mr_range['MR0'] > 0]['MR1'] / data_mr_range[data_mr_range['MR0'] > 0]['MR0'] - 1
+        )
+
+        data_mr_range = xs_pos(data=data_mr_range, quantile=quantile)
+
+        data_t = data[
+            np.array(data['TDATE'] == t_date) & np.array(data['VOL'] > kwargs['min_volume'])
+            ][['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', price_field]]
+
+        data_liq = data[
+            data['TDATE'] == calendar[i - liq_days]
+            ][['UCODE']]
+
+        data_t = pd.merge(data_liq, data_t, on='UCODE', how='inner')
+
+        data_tomorrow = data[
+            np.array(data['TDATE'] == calendar[i + 1])
+        ][['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', price_field]]
+
+        data_t = pd.merge(data_t[['UCODE', price_field]], data_mr_range, on='UCODE', how='inner')
+
+        data_t = pd.merge(
+            data_t.rename(columns={price_field: 'CLOSE'}),
+            data_tomorrow.rename(columns={price_field: 'CLOSE1'}),
+            on='UCODE', how='left'
+        )
+
+        data_t['RETURN'] = (data_t['CLOSE1'] / data_t['CLOSE'] - 1) #* data_t['POS']
+
+        # index_all.append(index_all[-1] * (1 + data_t['RETURN'].mean()))
+        data_t['TDATE'] = calendar[i + 1]
+        data_t['FACTOR'] = index_name
+        data_t = xs_weight(data_t)
+        positions = pd.concat([positions, data_t])
+        print(index_name + ', ' + t_date.strftime('%Y-%m-%d') + ', ' + str(sum(data_t['POS'] != 0)))
+    if len(positions) == 0:
+        return
+    positions['WEIGHT'] = positions['WEIGHT'] * 100
+    positions['RETURN'] = positions['RETURN'] * 100
+    # positions['FACTORVALUE'] = positions['FACTORVALUE'] * 100
+    return positions[
+        ['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', 'CLOSE', 'CLOSE1', 'POS', 'RETURN', 'FACTORVALUE', 'FACTOR', 'WEIGHT']
+    ].reset_index(drop=True)
+
+
 # n日净增减
 # 净变化为正做多
 def mrchg(start_date, price_field='CLOSE', lag=1, **kwargs):
@@ -824,6 +965,76 @@ def mrchg(start_date, price_field='CLOSE', lag=1, **kwargs):
     ].reset_index(drop=True)
 
 
+# n日净增减
+# 净变化排序
+def xsmrchg(start_date, price_field='CLOSE', lag=1, **kwargs):
+    data = kwargs['data']
+    data_mr = kwargs['data_mr']
+    liq_days = kwargs['liq_days']
+    data['UCODE'] = data['EXCHANGE'].apply(lambda x: str(x)) + data['PCODE'].apply(lambda x: str(x))
+    data_mr['UCODE'] = data_mr['EXCHANGE'].apply(lambda x: str(x)) + data_mr['PCODE'].apply(lambda x: str(x))
+
+    calendar = data['TDATE'].drop_duplicates().tolist()
+
+    quantile = kwargs['quantile']
+    window_days = kwargs['window_days']
+    index_name = 'xsmrchg_d' + str(window_days) + '_q' + str(quantile)
+
+    start_index = calendar.index(np.array(calendar)[np.array(calendar) >= start_date][0])
+
+    positions = pd.DataFrame()
+    for i in range(start_index, len(calendar) - 1):
+        t_date = calendar[i]
+        data_mr_t = data_mr[
+            np.array(data_mr['TDATE'] >= calendar[i - lag - window_days])
+            & np.array(data_mr['TDATE'] <= calendar[i - lag])
+            ].groupby(by=['UCODE']).sum()[['MRCHG']].reset_index()
+        data_mr_range = data_mr_t
+
+        data_mr_range['FACTORVALUE'] = data_mr_range['MRCHG']
+
+        data_mr_range = xs_pos(data=data_mr_range, quantile=quantile)
+
+        data_t = data[
+            np.array(data['TDATE'] == t_date) & np.array(data['VOL'] > kwargs['min_volume'])
+            ][['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', price_field]]
+
+        data_liq = data[
+            data['TDATE'] == calendar[i - liq_days]
+            ][['UCODE']]
+
+        data_t = pd.merge(data_liq, data_t, on='UCODE', how='inner')
+
+        data_tomorrow = data[
+            np.array(data['TDATE'] == calendar[i + 1])
+        ][['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', price_field]]
+
+        data_t = pd.merge(data_t[['UCODE', price_field]], data_mr_range, on='UCODE', how='inner')
+
+        data_t = pd.merge(
+            data_t.rename(columns={price_field: 'CLOSE'}),
+            data_tomorrow.rename(columns={price_field: 'CLOSE1'}),
+            on='UCODE', how='left'
+        )
+
+        data_t['RETURN'] = (data_t['CLOSE1'] / data_t['CLOSE'] - 1) #* data_t['POS']
+
+        # index_all.append(index_all[-1] * (1 + data_t['RETURN'].mean()))
+        data_t['TDATE'] = calendar[i + 1]
+        data_t['FACTOR'] = index_name
+        data_t = xs_weight(data_t)
+        positions = pd.concat([positions, data_t])
+        print(index_name + ', ' + t_date.strftime('%Y-%m-%d') + ', ' + str(sum(data_t['POS'] != 0)))
+    if len(positions) == 0:
+        return
+    positions['WEIGHT'] = positions['WEIGHT'] * 100
+    positions['RETURN'] = positions['RETURN'] * 100
+    # positions['FACTORVALUE'] = positions['FACTORVALUE'] * 100
+    return positions[
+        ['TDATE', 'EXCHANGE', 'PCODE', 'UCODE', 'CLOSE', 'CLOSE1', 'POS', 'RETURN', 'FACTORVALUE', 'FACTOR', 'WEIGHT']
+    ].reset_index(drop=True)
+
+
 def tspoichg(start_date, **kwargs):
     data = kwargs['data']
     liq_days = kwargs['liq_days']
