@@ -481,11 +481,28 @@ def update_performance(start_d, end_d, funds, db_path, cal_db_path, month_releas
         funds_data_monthly = funds_data_monthly[funds_data_monthly['t_date'] >= start_d]
 
     result_monthly_ret = ret(funds_data_monthly)[1:].iloc[::-1]
-    result_key, result_dd, result_ret = performance_analysis(
-        funds_data[funds_data['t_date'] >= start_d].reset_index(drop=True), monthly_funds=month_release
-    )
 
-    result_key2, _, _ = performance_analysis(
+    funds_date = funds_data[['t_date']].copy()
+    funds_date.loc[:, 'year'] = pd.to_datetime(funds_data['t_date']).dt.year
+    funds_date = funds_date.drop_duplicates(subset=['year'], keep='last')
+    funds_date = funds_date[funds_date['year'] >= 2018].sort_values(by='year', ascending=False).reset_index(drop=True)
+    funds_date.loc[:, 'year1'] = funds_date['year'].shift(1)
+    funds_date = funds_date[1:5].reset_index(drop=True)
+
+    result_key = []
+    result_dd = []
+    result_ret = []
+    for d in range(len(funds_date)):
+        rrr = performance_analysis(
+            funds_data[funds_data['t_date'] >= start_d].reset_index(drop=True),
+            monthly_funds=month_release,
+            start_date=funds_date['t_date'][d],
+        )
+        result_key.append(rrr[0])
+        result_dd.append(rrr[1])
+        result_ret.append(rrr[2])
+
+    result_key0, _, _ = performance_analysis(
         funds_data[funds_data['t_date'] >= start_d].reset_index(drop=True), monthly_funds=month_release,
         start_date=funds_data['t_date'].tolist()[-52]
     )
@@ -516,13 +533,15 @@ def update_performance(start_d, end_d, funds, db_path, cal_db_path, month_releas
         }, index=fund_name_list
     ).T.reset_index()
 
-    results_all = result_date.append(result_specific).append(result_key2).append(result_key)
+    results_all = result_date.append(result_specific).append(result_key0)
+    for i in result_key:
+        results_all = results_all.append(i)
 
     nav_all = funds_data
 
-    dd_all = result_dd
+    dd_all = result_dd[-1]
 
-    weekly_ret_all = result_ret
+    weekly_ret_all = result_ret[-1]
 
     monthly_ret_all = result_monthly_ret
 
