@@ -21,6 +21,8 @@ class FundStats(object):
         '000852.SH': '中证1000'
     }
 
+    xw_box_line_weight = 3
+
     def __init__(self, start_date, end_date, output_path, fund_data_path, index_data_path, sort=1):
         self.row_num = row_num
         self.start_date = start_date
@@ -38,6 +40,7 @@ class FundStats(object):
         self.sum_zz_o = None
 
         self.long_only_stats = None
+        self.key_years = 4
 
     def sheet_style0(self, sht, input_main, fund_dict, bold_list=None, red_list=None, skip_list=['多头']):
 
@@ -56,57 +59,77 @@ class FundStats(object):
             sht.range('B' + str(row_n + 1)).value = input_data
             sht.range((row_n, 5), (row_n, 2 + self.m1c)).api.Merge()
             sht.range((row_n, 5)).value = '收益'
+            sht.range((row_n, 1), (row_n + 1 + len(input_data), 1)).api.Merge()
+            sht.range((row_n, 1)).value = t.replace('（', '\n（')
+            sht.range(
+                (row_n, 1), (row_n + 1 + len(input_data), 2 + self.m1c + self.m2c * 2)
+            ).api.Borders(8).LineStyle = 1
+            sht.range(
+                (row_n, 1),
+                (row_n + 1 + len(input_data), 2 + self.m1c + self.m2c * (1 + self.key_years))
+            ).api.Borders(8).Weight = self.xw_box_line_weight
+
+            sht.range((row_n, 1), (row_n + 1 + len(input_data), 2)).api.HorizontalAlignment = -4108
+            sht.range((row_n, 1), (row_n + 1 + len(input_data), 2)).api.VerticalAlignment = -4108
+
+            sht.range(
+                (row_n, 3),
+                (row_n + 1, 2 + self.m1c + self.m2c * (1 + self.key_years))
+            ).api.HorizontalAlignment = -4108
+            sht.range(
+                (row_n, 3),
+                (row_n + 1, 2 + self.m1c + self.m2c * (1 + self.key_years))
+            ).api.VerticalAlignment = -4108
+
+            sht.range((row_n + 2, 3), (row_n + 2 + len(input_data), 3)).api.NumberFormat = "yyyy/mm"
+            sht.range((row_n + 2, 4), (row_n + 2 + len(input_data), 4)).api.NumberFormat = "mm/dd"
+            sht.range((row_n + 2, 5), (row_n + 2 + len(input_data), 2 + self.m1c)).api.NumberFormat = "0.00%"
 
             sht.range((row_n, 3 + self.m1c), (row_n, 2 + self.m1c + self.m2c)).api.Merge()
             sht.range((row_n, 3 + self.m1c)).value = '近一年'
             sht.range(
                 (row_n, 3 + self.m1c), (row_n + 1 + len(input_data), 2 + self.m1c + self.m2c * 2)
             ).api.Borders(7).LineStyle = 2
-
-            sht.range((row_n, 3 + self.m1c + self.m2c), (row_n, 2 + self.m1c + self.m2c * 2)).api.Merge()
-            sht.range((row_n, 3 + self.m1c + self.m2c)).value = '2019以来'
             sht.range(
-                (row_n, 3 + self.m1c + self.m2c), (row_n + 1 + len(input_data), 2 + self.m1c + self.m2c * 2)
-            ).api.Borders(7).LineStyle = 2
-
-            sht.range((row_n, 1), (row_n + 1 + len(input_data), 1)).api.Merge()
-            sht.range((row_n, 1)).value = t.replace('（', '\n（')
+                (row_n, 3 + self.m1c), (row_n + 1 + len(input_data), 2 + self.m1c + self.m2c * 2)
+            ).api.Borders(7).Weight = self.xw_box_line_weight
             sht.range(
-                (row_n, 1), (row_n + 1 + len(input_data), 2 + self.m1c + self.m2c * 2)
-            ).api.Borders(8).LineStyle = 1
-            sht.range((row_n, 1), (row_n + 1 + len(input_data), 2 + self.m1c + self.m2c * 2)).api.Borders(8).Weight = 3
-
-            sht.range((row_n, 1), (row_n + 1 + len(input_data), 2)).api.HorizontalAlignment = -4108
-            sht.range((row_n, 1), (row_n + 1 + len(input_data), 2)).api.VerticalAlignment = -4108
-
-            sht.range((row_n, 3), (row_n + 1, 2 + self.m1c + self.m2c * 2)).api.HorizontalAlignment = -4108
-            sht.range((row_n, 3), (row_n + 1, 2 + self.m1c + self.m2c * 2)).api.VerticalAlignment = -4108
-
-            sht.range((row_n + 2, 3), (row_n + 2 + len(input_data), 3)).api.NumberFormat = "yyyy/mm"
-            sht.range((row_n + 2, 4), (row_n + 2 + len(input_data), 4)).api.NumberFormat = "mm/dd"
-            sht.range((row_n + 2, 5), (row_n + 2 + len(input_data), 7 + self.m1c)).api.NumberFormat = "0.00%"
-            sht.range(
-                (row_n + 2, 10 + self.m1c), (row_n + 2 + len(input_data), 12 + self.m1c)
-            ).api.NumberFormat = "0.00"
-            sht.range(
-                (row_n + 2, 13 + self.m1c), (row_n + 2 + len(input_data), 13 + self.m1c)
+                (row_n + 2, 3 + self.m1c),
+                (row_n + 2 + len(input_data), 3 + self.m1c + self.m2c)
             ).api.NumberFormat = "0.00%"
+            sht.range(
+                (row_n + 2, 8 + self.m1c), (row_n + 2 + len(input_data), 12 + self.m1c)
+            ).api.NumberFormat = "0.00"
             sht.range(
                 (row_n + 2, 14 + self.m1c), (row_n + 2 + len(input_data), 14 + self.m1c)
             ).api.NumberFormat = "0.00"
 
-            sht.range(
-                (row_n + 2, 3 + self.m1c + self.m2c), (row_n + 2 + len(input_data), 7 + self.m1c + self.m2c)
-            ).api.NumberFormat = "0.00%"
-            sht.range(
-                (row_n + 2, 10 + self.m1c + self.m2c), (row_n + 2 + len(input_data), 12 + self.m1c + self.m2c)
-            ).api.NumberFormat = "0.00"
-            sht.range(
-                (row_n + 2, 13 + self.m1c + self.m2c), (row_n + 2 + len(input_data), 13 + self.m1c + self.m2c)
-            ).api.NumberFormat = "0.00%"
-            sht.range(
-                (row_n + 2, 14 + self.m1c + self.m2c), (row_n + 2 + len(input_data), 14 + self.m1c + self.m2c)
-            ).api.NumberFormat = "0.00"
+            for y in range(self.key_years):
+                sht.range(
+                    (row_n, 3 + self.m1c + self.m2c * (1 + y)),
+                    (row_n, 2 + self.m1c + self.m2c * (2 + y))
+                ).api.Merge()
+                sht.range((row_n, 3 + self.m1c + self.m2c * (1 + y))).value = input_data.columns[7 + y] + '以来'
+                sht.range(
+                    (row_n, 3 + self.m1c + self.m2c * (1 + y)),
+                    (row_n + 1 + len(input_data), 2 + self.m1c + self.m2c * (2 + y))
+                ).api.Borders(7).LineStyle = 2
+                sht.range(
+                    (row_n, 3 + self.m1c + self.m2c * (1 + y)),
+                    (row_n + 1 + len(input_data), 2 + self.m1c + self.m2c * (2 + y))
+                ).api.Borders(7).Weight = self.xw_box_line_weight
+                sht.range(
+                    (row_n + 2, 3 + self.m1c + self.m2c * (1 + y)),
+                    (row_n + 2 + len(input_data), 2 + self.m1c + self.m2c * (1 + y + 1))
+                ).api.NumberFormat = "0.00%"
+                sht.range(
+                    (row_n + 2, 3 + self.m1c + self.m2c * (1 + y) + 5),
+                    (row_n + 2 + len(input_data), 2 + self.m1c + self.m2c * (1 + y + 1) - 2)
+                ).api.NumberFormat = "0.00"
+                sht.range(
+                    (row_n + 2, 2 + self.m1c + self.m2c * (1 + y + 1)),
+                    (row_n + 2 + len(input_data), 2 + self.m1c + self.m2c * (1 + y + 1))
+                ).api.NumberFormat = "0.00"
 
             for i in range(len(input_data)):
                 if bold_list is not None:
@@ -192,7 +215,7 @@ class FundStats(object):
             cal_db_path=self.index_path,
             month_release=month_list
         )
-        self.m1c = len(data['main']) - 2 * self.m2c
+        self.m1c = len(data['main']) - (1 + self.key_years) * self.m2c
         if fund_type.lower() == 'zz':
             order_all = order
             order = []
@@ -247,7 +270,7 @@ class FundStats(object):
                 if t == '多头':
                     continue
                 rowl = len(fund_dict[t])
-                for i in range(3, 3 + self.m1c + 2 * self.m2c - 1):
+                for i in range(3, 3 + self.m1c + (1 + self.key_years) * self.m2c - 1):
                     col = ten2twentysix(i)
                     if i in list(np.array([5, 7, 8, 17, 19, 20]) + self.m1c):
                         sheet1.conditional_format(col + str(row_n + 1) + ':' + col + str(row_n + rowl), cell_format_r)
@@ -270,7 +293,7 @@ class FundStats(object):
                     else:
                         fund_dict_i[t] = fund_dict[t] + ['中证500']
                 rowl = len(fund_dict_i[t])
-                for i in range(3, 3 + self.m1c + 2 * self.m2c - 1):
+                for i in range(3, 3 + self.m1c + (1 + self.key_years) * self.m2c - 1):
                     col = ten2twentysix(i)
                     if i in list(np.array([5, 7, 8, 17, 19, 20]) + self.m1c):
                         sheet12.conditional_format(col + str(row_n + 1) + ':' + col + str(row_n + rowl), cell_format_r)
@@ -297,7 +320,7 @@ class FundStats(object):
             row_n = self.row_num
             for t in fund_dict:
                 rowl = len(fund_dict[t])
-                for i in range(3, 3 + self.m1c + 2 * self.m2c - 1):
+                for i in range(3, 3 + self.m1c + (1 + self.key_years) * self.m2c - 1):
                     col = ten2twentysix(i)
                     if i in list(np.array([5, 7, 8, 17, 19, 20]) + self.m1c):
                         sheet1.conditional_format(col + str(row_n + 1) + ':' + col + str(row_n + rowl), cell_format_r)
