@@ -25,22 +25,24 @@ class FundNavAnalysor:
 
     def _load_data(self):
         trading_day_list = get_trading_day_list(self.start_date, self.end_date, frequency="week")
-        nav_series = self.nav_series.reindex(trading_day_list)
+        nav_series = self.nav_series.reindex(trading_day_list).dropna()
+        # nav_series = self.nav_series.reindex(trading_day_list).fillna(method='ffill').dropna()
         # benchmark
         sql_script = "SELECT JYRQ as TRADEDATE, ZQMC as INDEXNAME, SPJG as TCLOSE from funddb.ZSJY WHERE ZQDM = '{}' " \
                      "and JYRQ >= {} and JYRQ <= {}".format(self.benchmark_id, self.start_date, self.end_date)
-        res = hbs.db_data_query('readonly', sql_script)
+        res = hbs.db_data_query('readonly', sql_script, page_size=5000)
         map_dict = {"000905": "中证500", "000300": "沪深300", "000852": "中证1000"}
         benchmark_name = map_dict[self.benchmark_id]
         data = pd.DataFrame(res['data']).rename(columns={"TCLOSE": benchmark_name}).set_index(
             'TRADEDATE')[[benchmark_name]]
-        benchmark_df = data.reindex(trading_day_list)
+        benchmark_df = data.reindex(nav_series.index)
 
         assert (nav_series.shape[0] == benchmark_df.shape[0])
 
         nav_df = pd.merge(nav_series, benchmark_df, left_index=True, right_index=True)
         return_df = nav_df.pct_change().fillna(0.)
         return_df['超额'] = return_df[return_df.columns[0]] - return_df[benchmark_name]
+        # return_df['超额'] = return_df[return_df.columns[0]]
 
         self.nav_df = (1 + return_df).cumprod()
         self.return_df = return_df[1:]
@@ -78,6 +80,7 @@ class FundNavAnalysor:
             title=dict(text=title_text),
             autosize=False, width=fig_width, height=fig_height,
             yaxis=dict(tickfont=dict(size=12), showgrid=True),
+            # xaxis=dict(showgrid=True),
             xaxis=dict(showgrid=True, tickvals=tick_vals, ticktext=tick_text),
             legend=dict(orientation="h", x=0.35, y=1.1),
             template='simple_white',
@@ -146,8 +149,27 @@ class FundNavAnalysor:
 
 
 if __name__ == '__main__':
-    nv_series = get_fund_nav_from_sql('20170721', '20220218', {"天演6号": "SN1819"})
-    FundNavAnalysor('20170721', '20220218', '000905', nv_series).run()
+    # nv_series = get_fund_nav_from_sql('20211231', '20220311', {"白鹭精选量化鲲鹏十号": "SQB109"})
+    # nv_series = pd.read_excel("C:\\Users\\kai.zhang\\Desktop\\FACTSHEET 基准比较 - 副本.xlsx", sheet_name=0, index_col=0)
+    # nv_series['trade_date'] = nv_series.index
+    # nv_series['trade_date'] = nv_series['trade_date'].apply(lambda x: datetime.strftime(x, '%Y%m%d'))
+    # nv_series = nv_series.set_index('trade_date')['量派睿核十号']
+    #
+
+    # nv_series = pd.read_excel('D:\\平行公理拼接净值.xlsx', sheet_name=2)
+    # nv_series['日期'] = nv_series['日期'].apply(lambda x: datetime.strftime(x, '%Y%m%d'))
+    # nv_series = nv_series.set_index('日期')['拼接净值']
+
+    # nv_series1 = get_fund_nav_from_sql('20200306', '20211231', {"白鹭alpha": "SJM897"})
+    # return_series1 = nv_series1.pct_change().fillna(0.)
+    # nv_series2 = get_fund_nav_from_sql('20211231', '20220318', {"白鹭alpha": "SQB109"})
+    # return_series2 = nv_series2.pct_change().dropna()
+    # return_series = pd.concat([return_series1, return_series2], axis=0).sort_index()
+    # nv_series = (1 + return_series).cumprod()
+
+    nv_series = get_fund_nav_from_sql('20220114', '20220325', {"伯兄永康": "STQ128"})
+
+    FundNavAnalysor('20220114', '20220325', '000852', nv_series).run()
     # nv_series = pd.read_excel(
     #     "D:\\研究基地\\L-From_路遥\\1-跟踪代销\\天演\\净值文件\\天演资本代表产品净值20220106.xlsx", sheet_name="300指增", header=1, index_col=0)
     # nv_series['trade_date'] = nv_series.index
