@@ -378,7 +378,7 @@ class HoldingDistribution:
 if __name__ == '__main__':
     # d_list = ['20201231', '20210131', '20210228']
     # tmp = HoldingAnalysor("星阔广厦1号中证500指数增强", "20220128", "000905").get_construct_result(isPlot=False)
-    tmp = HoldingAnalysor("因诺聚配中证500指数增强", "20220131", "000905").get_construct_result(isPlot=True)
+    tmp = HoldingAnalysor("星阔广厦1号中证500指数增强", "20210730", "000905").get_construct_result(isPlot=True)
     # print(tmp['style_df'])
     # dis_df = HoldingDistribution('20210310', '20211118', '因诺聚配中证500指数增强').get_construct_result()
     # print(dis_df)
\ No newline at end of file
