@@ -16,11 +16,13 @@ import pyecharts.options as opts
 from pyecharts.charts import Bar, Timeline
 import plotly.figure_factory as ff
 from hbshare.db.simu import valuation
+from hbshare.fe.XZ import  db_engine
 
 # from plotly.offline import plot as plot_ly
 
 # plotly.offline.init_notebook_mode(connected=True)
 
+hbdb=db_engine.HBDB()
 
 def plot_render(plot_dic, width=1200, height=600, **kwargs):
     kwargs['output_type'] = 'div'
@@ -315,11 +317,17 @@ class HoldingAnalysor:
         else:self._load_data(inputdf)
 
     def _load_portfolio_weight(self):
-        sql_script = "SELECT * FROM subjective_fund_holding where fund_name = '{}' and " \
-                     "trade_date >= {} and trade_date <= {}".format(self.fund_name, self.start_date, self.end_date)
-        engine = create_engine(engine_params)
-        holding_df = pd.read_sql(sql_script, engine)
-        holding_df['trade_date'] = holding_df['trade_date'].apply(lambda x: datetime.datetime.strftime(x, '%Y%m%d'))
+        # sql_script = "SELECT * FROM subjective_fund_holding where fund_name = '{}' and " \
+        #              "trade_date >= {} and trade_date <= {}".format(self.fund_name, self.start_date, self.end_date)
+        # engine = create_engine(engine_params)
+        # holding_df = pd.read_sql(sql_script, engine)
+        # holding_df['trade_date'] = holding_df['trade_date'].apply(lambda x: datetime.datetime.strftime(x, '%Y%m%d'))
+
+
+        sql="select * from st_hedge.r_st_sm_subjective_fund_holding where jjdm='{0}' and trade_date >= '{1}' and trade_date <= '{2}' "\
+            .format(self.fund_name,self.start_date,self.end_date)
+        holding_df=hbdb.db2df(sql,db='highuser')
+        holding_df['trade_date']=holding_df['trade_date'].astype(str)
 
         return holding_df[['trade_date', 'ticker', 'sec_name', 'weight']]
 
@@ -774,9 +782,10 @@ class HoldingExtractor_DB:
 
     def _load_portfolio_weight(self,jjdm,date_list,fund_name=None):
 
-        date_list=self.to_month_date(date_list)
+        #date_list=self.to_month_date(date_list)
 
         portfolio_weight_list = []
+        error=''
         for date in date_list:
 
             try:
@@ -784,6 +793,7 @@ class HoldingExtractor_DB:
                 data=valuation.get_prod_valuation_by_jjdm_gzrq(jjdm,date)
                 if(data.empty):
                     print("data for {0} missed,continue...".format(date))
+                    error+="data for {0} missed,continue...;".format(date)
                     continue
                 date = self._shift_date(str(date))
                 columns_map=dict(zip(['kmdm','sz','kmmc'],['科目代码','市值','科目名称']))
@@ -834,6 +844,7 @@ class HoldingExtractor_DB:
 
                 if(len(sh)==0 and len(sz)==0 and len(cyb)==0 and len(kcb)==0):
                     print('No stock exist for {0} at {1}..'.format(jjdm,date))
+                    error+='No stock exist for {0} at {1}..;'.format(jjdm,date)
                     continue
 
                 equity_a = pd.concat([sh, sz, cyb, kcb], axis=0)
@@ -842,6 +853,7 @@ class HoldingExtractor_DB:
                 equity_a = equity_a[equity_a['len'] > 10]
                 if(len(equity_a)==0):
                     print('No stock details found in the data, date {} is skipped'.format(date))
+                    error+='No stock details found in the data, date {} is skipped;'.format(date)
                     continue
 
                 if("." not in equity_a['科目代码'].values[0]):
@@ -893,6 +905,7 @@ class HoldingExtractor_DB:
 
             except Exception as e:
                 print(str(e)+"for jjdm:{0} at date :{1}".format(jjdm,date))
+                error+=str(e)+"for jjdm:{0} at date :{1}".format(jjdm,date)
                 continue
 
         if(len(portfolio_weight_list)>0):
@@ -902,6 +915,7 @@ class HoldingExtractor_DB:
                                                           data=[['','',99999,date]])])
 
         portfolio_weight_df['jjdm'] = jjdm
+        portfolio_weight_df['error_list']=error
 
         return  portfolio_weight_df
 
@@ -923,12 +937,12 @@ if __name__ == '__main__':
     name='丹羿精选3号，无股票'
     name='亘曦2号,没有估值表'
 
-    jjdm = 'P02494'
-    # jjdm='P04365'
-    date_list =[ '20160630', '20160930', '20161230', '20170331', '20170630', '20170929']
+
+    # jjdm = 'P02494'
+    jjdm='S29129'
+    date_list =[ '20220302', '20220309', '20220316', '20220323']
     # date_list = ['20150630', '20150930']
     data=HoldingExtractor_DB()._load_portfolio_weight(jjdm=jjdm,date_list=date_list)
-    # date_list=['20150630','20150930'])
 
     # name_list=['同犇1期']
     # code_list=['P04365']
@@ -960,4 +974,4 @@ if __name__ == '__main__':
     #         .writeToDB(fromdb=True)
     #     print("{} done".format(name))
 
-    # HoldingAnalysor('新方程泓澄精选', start_date='20150831', end_date='20210630').get_construct_result()
\ No newline at end of file
+    HoldingAnalysor('S29129', start_date='20220302', end_date='20220316').get_construct_result()
\ No newline at end of file
